@@ -5,6 +5,8 @@
 
 import logging
 
+from mvt.android.parsers import parse_dumpsys_accessibility
+
 from .base import AndroidExtraction
 
 log = logging.getLogger(__name__)
@@ -20,45 +22,24 @@ class DumpsysAccessibility(AndroidExtraction):
                          log=log, results=results)
 
     def check_indicators(self):
+        if not self.indicators:
+            return
+
         for result in self.results:
-            ioc = self.indicators.check_app_id(result["package"])
+            ioc = self.indicators.check_app_id(result["package_name"])
             if ioc:
                 result["matched_indicator"] = ioc
                 self.detected.append(result)
                 continue
 
-    @staticmethod
-    def parse_accessibility(output):
-        results = []
-
-        in_services = False
-        for line in output.split("\n"):
-            if line.strip().startswith("installed services:"):
-                in_services = True
-                continue
-
-            if not in_services:
-                continue
-
-            if line.strip() == "}":
-                break
-
-            service = line.split(":")[1].strip()
-            log.info("Found installed accessibility service \"%s\"", service)
-
-            results.append({
-                "package": service.split("/")[0],
-                "service": service,
-            })
-
-        return results
-
     def run(self):
         self._adb_connect()
-
         output = self._adb_command("dumpsys accessibility")
-        self.results = self.parse_accessibility(output)
+        self._adb_disconnect()
+
+        self.results = parse_dumpsys_accessibility(output)
+
+        for result in self.results:
+            log.info("Found installed accessibility service \"%s\"", result.get("service"))
 
         self.log.info("Identified a total of %d accessibility services", len(self.results))
-
-        self._adb_disconnect()
