@@ -31,11 +31,6 @@ ANDROID_DANGEROUS_SETTINGS = [
         "key": "upload_apk_enable",
         "safe_value": "1",
     },
-    {
-        "description": "enabled installation of non-market apps",
-        "key": "install_non_market_apps",
-        "safe_value": "0",
-    },
     {
         "description": "disabled confirmation of adb apps installation",
         "key": "adb_install_need_confirm",
